#ifndef ManipulatorVisualization_H
#define ManipulatorVisualization_H

//Coin includes
#include <Inventor/nodes/SoSeparator.h>
#include <Inventor/manips/SoTransformerManip.h>

//VirtualRobot
#include <VirtualRobot/Robot.h>
#include <VirtualRobot/Visualization/CoinVisualization/CoinVisualization.h>

//Boost includes
#include <boost/smart_ptr/intrusive_ptr.hpp>


//Let boost use referencing of Inventor to manage objects memory
//and not its own shared pointer referencing
typedef boost::intrusive_ptr<SoTransformerManip> SoTransformerManipPtr;
inline void intrusive_ptr_add_ref(SoTransformerManip* obj)
{
    obj->ref();
}
inline void intrusive_ptr_release(SoTransformerManip* obj)
{
    obj->unref();
}

typedef boost::shared_ptr<VirtualRobot::CoinVisualization> CoinVisualizationPtr;

class ManipulatorVisualization : SoSeparator {
    public:
        ManipulatorVisualization();
        ~ManipulatorVisualization();

        void setVisualization(VirtualRobot::RobotPtr robot, VirtualRobot::RobotNodeSetPtr nodeSet);
        void removeVisualization();

        void addManipFinishCallback(SoDraggerCB* func, void* data);
        void addManipMovedCallback(SoDraggerCB* func, void* data);

        Eigen::Matrix4f getUserDesiredPose();
        std::string getUserDesiredPoseString();

        bool getIsVisualizing() {return isVisualizing;}

    private:
        SoTransformerManipPtr manip;
        bool isVisualizing;
};

#endif
